<?xml version="1.0" encoding="utf-8"?>

<!-- ====================================================================== 

     ====================================================================== -->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:h="http://www.w3.org/1999/xhtml"
		xmlns:doc = "http://xsltsl.org/xsl/documentation/1.0"
		exclude-result-prefixes = "doc"
                version="1.0">

<!-- ====================================================================== 

     ====================================================================== -->

     <doc:reference>
      <referenceinfo>

       <title>article2s5-starter</title>

       <abstract>
        <para>article2s5-starter is an <acronym>XSLT</acronym>
        stylesheet for converting a DocBook article into a
        draft-quality Simple Standards-Based Slide Show System
        (S5) <acronym>XHTML</acronym> presentation.</para>

	<para>This is a tool for automating some tedious work
	required to create a presentation. Its functionality is, while
	useful, limited. Presentations are created as follows :</para>

	<itemizedlist>
	 <listitem>
	  <para>A title slide, containing author and date information.</para>
	 </listitem>
	 <listitem>
	  <para>An introductory slide, containing the article's abstract.</para>
	 </listitem>
	 <listitem>
	  <para>One slide for every section block in the article,
	  including nested sections. Each slide will contain the
	  section's title and, if defined, its abstract.</para>
	 </listitem>
	 <listitem>
	  <para>A final slide containing copyright information.</para>
	 </listitem>
	</itemizedlist>

	<para>Because an essay and a presentation are sufficiently
	different the stylesheet does not try to divine anymore than
	some basic structure. It is expected that an author will
	continue to make edits to the presentation in a manner that
	will best convey their message.</para>

	<para>It is also not a replacement for the more robust
	DocBook <acronym>XSLT</acronym> stylesheets meaning anything but
	the most basic markup is ignored.</para> 

       </abstract>

       <author>
	<surname>Cope</surname>
	<firstname>Aaron</firstname>
	<othername>Straup</othername>
	<email>aaron@aaronland.net</email>
       </author>

       <legalnotice>
        <para>This work is licensed under the Creative Commons
        Attribution-ShareAlike License. To view a copy of this
        license, visit <ulink url = "http://creativecommons.org/licenses/by-sa/1.0/">http://creativecommons.org/licenses/by-sa/1.0/</ulink> or send a letter to Creative Commons, 559 Nathan Abbott Way,
        Stanford, California 94305, USA.</para> 
       </legalnotice>

       <revhistory>
        <revision>
	 <revnumber>1.0</revnumber>
	 <date>2004-11-22</date>
	 <revremark>
	  <para>Initial release.</para>
         </revremark>
	</revision>
       </revhistory>

      </referenceinfo>

      <refentry>
       <refsection>
        <title>Usage</title>

	<example>
	 <programlisting><![CDATA[
 $> xsltproc --stringparam s5data '/my/css/s5' \
             -o example.html \
             article2s5-starter.xsl \
             example.xml
]]></programlisting>
	</example>
	 
	<para>Consult the documentation for your favourite  <acronym>XSLT</acronym> processor.</para>

       </refsection>

       <refsection>
        <title>Options</title>
	<para>article2s5-starter accepts the following parameters:</para>
	<itemizedlist>
	 <listitem>
	  <formalpara>
	   <title>s5data</title>
	   <para>The URI for the S5 <acronym>CSS</acronym> and JavaScript files. Default is <quote>ui</quote>.</para>
	  </formalpara>
	 </listitem>
	</itemizedlist>
       </refsection>

       <refsection>
        <title>Requirements</title>
	<para>Nothing special.</para>
       </refsection>

       <refsection>
	<title>CSS</title>

	<para>The S5 slide presentation tool defines a number
	of <acronym>CSS</acronym> styles that may be used to alter
	the layout of your presentation. The article2s5-starter tool
	also assigns the following classes :</para>

	<itemizedlist>

	 <listitem>
	  <formalpara>
	   <title>dbk-affiliation</title>
	   <para>This class is assigned to a block level element
	   containing information about an author's, affiliations.</para>
	  </formalpara>
	 </listitem>

	 <listitem>
	  <formalpara>
	   <title>dbk-author</title>
	   <para>This class is assigned to a block level element
	   containing an author's name and their affiliations.</para>
	  </formalpara>
	 </listitem>

	 <listitem>
	  <formalpara>
	   <title>dbk-authorgroup</title>
	   <para>This class is assigned to a block level element (an
	   unorderlist) containing a list of authors and editors.</para>
	  </formalpara>
	 </listitem>

	 <listitem>
	  <formalpara>
	   <title>dbk-copyright</title>
	   <para>This class is assigned to a block level element
	   containing copyright information.</para>
	  </formalpara>
	 </listitem>

	 <listitem>
	  <formalpara>
	   <title>dbk-editor</title>
	   <para>This class is assigned to a block level element
	   containing an editor's name and their affiliations.</para>
	  </formalpara>
	 </listitem>

	 <listitem>
	  <formalpara>
	   <title>dbk-fptitle</title>
	   <para>This class is assigned to an inline element
	   containing the title of a DocBook &lt;formalpara&gt; block.</para>
	  </formalpara>
	 </listitem>

	 <listitem>
	  <formalpara>
	   <title>dbk-legalnotice</title>
	   <para>This class is assigned to a block level element
	   containing copyright licensing information or other legal
	   notices.</para>
	  </formalpara>
	 </listitem>

        </itemizedlist>

      </refsection>

       <refsection>
	<title>Appendix</title>
	<itemizedlist>
	 <listitem>
	  <formalpara>
	   <title>Cascading Style Sheets (CSS)</title>
	   <para><ulink url = "http://www.w3.org/Style/CSS/" /></para>
	  </formalpara>
	 </listitem>
	 <listitem>
	  <formalpara>
	   <title>DocBook</title>
	   <para><ulink url = "http://www.docbook.org" /></para>
	  </formalpara>
	 </listitem>
	 <listitem>
	  <formalpara>
	   <title>Simple Standards-Based Slide Show System (S5)</title>
	   <para><ulink url = "http://www.meyerweb.com/eric/tools/s5/" /></para>
	  </formalpara>
	 </listitem>
	 <listitem>
	  <formalpara>
	   <title>Extensible Hyper Text Markup Language (XHTML)</title>
	   <para><ulink url = "http://www.w3.org/MarkUp/" /></para>
	  </formalpara>
	 </listitem>
	</itemizedlist>
       </refsection>

      </refentry>

     </doc:reference>

<!-- ====================================================================== 

     ====================================================================== -->

  <xsl:output method = "xml"/>
  <xsl:output indent = "yes"/>

  <xsl:output doctype-public = "-//W3C//DTD XHTML 1.1//EN" />
  <xsl:output doctype-system = "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd" />

<!-- ====================================================================== 

     ====================================================================== -->

  <xsl:param name = "s5data" select = "'ui'" />

  <xsl:variable name = "title">
   <xsl:call-template name = "title" />
  </xsl:variable>

  <xsl:variable name = "subtitle">
   <xsl:call-template name = "subtitle" />
  </xsl:variable>

<!-- ====================================================================== 

     ====================================================================== -->

  <xsl:template match="/">
   <h:html xmlns="http://www.w3.org/1999/xhtml">
    <xsl:call-template name = "head" />
    <h:body>
     <xsl:call-template name = "layout" />
     <xsl:call-template name = "presentation" />
     </h:body>
    </h:html>

   </xsl:template>

<!-- ====================================================================== 

     ====================================================================== -->

  <xsl:template match = "authorgroup">
   <h:ul class = "dbk-authorgroup">
    <xsl:for-each select = "child::node()[name() = 'author' or name() = 'editor']">
     <li><xsl:apply-templates select = "." /></li>
    </xsl:for-each>
  </h:ul>
  </xsl:template>

<!-- ====================================================================== 

     ====================================================================== -->

  <xsl:template match = "author|editor">
   <h:div>
    <xsl:attribute name = "class">
     <xsl:text>dbk-</xsl:text>
     <xsl:value-of select = "name()" />
    </xsl:attribute>
    <h:span class = "firstname"><xsl:value-of select = "firstname" /></h:span>
    <xsl:text> </xsl:text>
    <h:span class = "othername"><xsl:value-of select = "othername" /></h:span>
    <xsl:text> </xsl:text>
    <h:span class = "surname"><xsl:value-of select = "surname" /></h:span>
    <xsl:apply-templates select = "affiliation" />
   </h:div>
  </xsl:template>

<!-- ====================================================================== 

     ====================================================================== -->

  <xsl:template match = "affiliation">
   <h:div class = "dbk-affiliation">
    <xsl:choose>
     <xsl:when test = "shortaffil">
      <xsl:value-of select = "shortaffil" />
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select = "jobtitle" />
      <xsl:text> </xsl:text>
      <xsl:value-of select = "orgname" />
     </xsl:otherwise>
    </xsl:choose>
   </h:div>
  </xsl:template>

<!-- ====================================================================== 

     ====================================================================== -->

  <xsl:template match = "section">
    <h:div class = "slide">
     <h:h1>
      <xsl:choose>
       <xsl:when test = "sectioninfo/title">
	<xsl:value-of select = "sectioninfo/title" />
       </xsl:when>
       <xsl:when test = "title">
	<xsl:value-of select = "title" />
       </xsl:when>
       <xsl:otherwise>
	<xsl:text>slide </xsl:text>
	<xsl:value-of select = "position()" />
       </xsl:otherwise>
      </xsl:choose>
     </h:h1>
     <xsl:apply-templates select = "sectioninfo/abstract" />
    </h:div>

    <xsl:apply-templates select = "./section" />
  </xsl:template>

<!-- ====================================================================== 

     ====================================================================== -->

  <xsl:template match = "abstract">
   <h:div class = "abstract">
    <xsl:apply-templates select = "*" />
   </h:div>
  </xsl:template>

<!-- ====================================================================== 

     ====================================================================== -->

  <xsl:template match = "para|simplepara">
   <h:p><xsl:value-of select = "." /></h:p>
  </xsl:template>

<!-- ====================================================================== 

     ====================================================================== -->

  <xsl:template match = "formalpara">
   <h:p>
    <h:span class = "dbk-fptitle">
     <xsl:value-of select = "title" />
    </h:span>
    <xsl:value-of select = "para" />
   </h:p>
  </xsl:template>

<!-- ====================================================================== 

     ====================================================================== -->

  <xsl:template name = "title">
   <xsl:choose>
    <xsl:when test = "/article/articleinfo/title">
     <xsl:value-of select = "/article/articleinfo/title" />
    </xsl:when>
    <xsl:when test = "/article/title">
     <xsl:value-of select = "/article/title" />
    </xsl:when>
    <xsl:otherwise />
   </xsl:choose>
  </xsl:template>

<!-- ====================================================================== 

     ====================================================================== -->

  <xsl:template name = "subtitle">
   <xsl:choose>
    <xsl:when test = "/article/articleinfo/subtitle">
     <xsl:value-of select = "/article/articleinfo/subtitle" />
    </xsl:when>
    <xsl:when test = "/article/subtitle">
     <xsl:value-of select = "/article/subtitle" />
    </xsl:when>
    <xsl:otherwise />
   </xsl:choose>
  </xsl:template>

<!-- ====================================================================== 

     ====================================================================== -->

  <xsl:template name = "head">
    <h:head>
     <h:title>
      <xsl:value-of select = "$title" />
      <xsl:if test = "$subtitle">
       <xsl:text> &#8212; </xsl:text>
       <xsl:value-of select = "$subtitle" />
      </xsl:if>
    </h:title>
    <h:meta name="version" content="S5 1.0" />

    <xsl:call-template name = "css-link">
     <xsl:with-param name = "media" select = "'projection'" />
     <xsl:with-param name = "id" select = "'slideProj'" />
     <xsl:with-param name = "href" select = "'slides.css'" />
    </xsl:call-template>

    <xsl:call-template name = "css-link">
     <xsl:with-param name = "media" select = "'projection'" />
     <xsl:with-param name = "id" select = "'operaFix'" />
     <xsl:with-param name = "href" select = "'opera.css'" />
    </xsl:call-template>

    <xsl:call-template name = "css-link">
     <xsl:with-param name = "media" select = "'print'" />
     <xsl:with-param name = "id" select = "'slidePrint'" />
     <xsl:with-param name = "href" select = "'print.css'" />
    </xsl:call-template>

    <h:script>
     <xsl:attribute name = "type">
      <xsl:text>text/javascript</xsl:text>
     </xsl:attribute>
     <xsl:attribute name = "src">
      <xsl:value-of select = "$s5data" />
      <xsl:text>/slides.js</xsl:text>
     </xsl:attribute>
     <xsl:text>//</xsl:text>
    </h:script>

   </h:head>
  </xsl:template>

<!-- ====================================================================== 

     ====================================================================== -->

  <xsl:template name = "layout">
    <h:div class="layout">
     <h:div id="currentSlide">&#160;</h:div>
     <h:div id="header">&#160;</h:div>
     <h:div id="footer">
      <h:h1><xsl:value-of select = "/article/articleinfo/pubdate" /></h:h1>
      <h:h2><xsl:value-of select = "$title" /></h:h2>
      <h:div id="controls">&#160;</h:div>
     </h:div>
    </h:div>
  </xsl:template>

<!-- ====================================================================== 

     ====================================================================== -->

  <xsl:template name = "presentation">
     <h:div class="presentation">
      <xsl:call-template name = "splash" />
      <xsl:call-template name = "abstract" />
      <xsl:call-template name = "slides" />
      <xsl:call-template name = "copyright" />
     </h:div>
  </xsl:template>

<!-- ====================================================================== 

     ====================================================================== -->

  <xsl:template name = "splash">
      <h:div class="slide">
       <h:h1><xsl:value-of select = "$title" /></h:h1>

       <xsl:if test = "$subtitle">
	<h:h2><xsl:value-of select = "$subtitle" /></h:h2>
       </xsl:if>

       <xsl:apply-templates select =
       "/article/articleinfo/child::node()[name() = 'author' or name() = 'editor' or name() = 'authorgroup']" />
      </h:div>
  </xsl:template>

<!-- ====================================================================== 

     ====================================================================== -->

  <xsl:template name = "abstract">
      <h:div class = "slide">
       <xsl:apply-templates select = "/article/articleinfo/abstract" />
      </h:div>
  </xsl:template>

<!-- ====================================================================== 

     ====================================================================== -->

  <xsl:template name = "slides">
   <xsl:apply-templates select = "/article/section" />
  </xsl:template>

<!-- ====================================================================== 

     ====================================================================== -->

  <xsl:template name = "copyright">
   <h:div class = "slide">
    <h:div class = "dbk-copyright">
     <xsl:text>Copyright &#169; </xsl:text>
     <xsl:value-of select = "/article/articleinfo/copyright/year" />
     <xsl:text> </xsl:text>
     <xsl:value-of select = "/article/articleinfo/copyright/holder" />
     <xsl:text> </xsl:text>
    </h:div>
    <h:div class = "dbk-legalnotice">
     <xsl:value-of select = "/article/articleinfo/legalnotice" />
    </h:div>						   
   </h:div>
  </xsl:template>

  <xsl:template name = "css-link">
    <xsl:param name = "media" />
    <xsl:param name = "id" />
    <xsl:param name = "href" />

    <h:link>
     <xsl:attribute name = "rel">stylesheet</xsl:attribute>
     <xsl:attribute name = "type">text/css</xsl:attribute>
     <xsl:attribute name = "media">
      <xsl:value-of select = "$media" />
     </xsl:attribute>
     <xsl:attribute name = "id">
      <xsl:value-of select = "$id" />
     </xsl:attribute>
     <xsl:attribute name = "href">
      <xsl:value-of select = "$s5data" />
      <xsl:text>/</xsl:text>
      <xsl:value-of select = "$href" />      
     </xsl:attribute>
    </h:link>
  </xsl:template>

<!-- ====================================================================== 
     FIN // $Id: article2s5-starter.xsl,v 1.2 2004/11/21 14:20:30 asc Exp $
     ====================================================================== -->

</xsl:stylesheet>
